/*----------------------------------------------------------------------------
 * Name:    Blinky.c
 * Purpose: Freescale MKE04Z8xxx4 LED Flasher
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2013 - 2017 Keil - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/
#include "MKE06Z4.h"                    // Device header


#define LED_NUM     3                   /* Number of user LEDs                */
const uint32_t led_mask[] = {1UL << 21, 1UL << 22, 1UL << 23};

volatile uint32_t msTicks;                            /* counts 1ms timeTicks */
/*----------------------------------------------------------------------------
  SysTick_Handler
 *----------------------------------------------------------------------------*/
void SysTick_Handler(void) {
  msTicks++;                        /* increment counter necessary in Delay() */
}

/*----------------------------------------------------------------------------
  delays number of tick Systicks (happens every 1 ms)
 *----------------------------------------------------------------------------*/
void Delay (uint32_t dlyTicks) {
  uint32_t curTicks;

  curTicks = msTicks;
  while ((msTicks - curTicks) < dlyTicks);
}

/*----------------------------------------------------------------------------
  configer LED pins
 *----------------------------------------------------------------------------*/
void LED_Initialize(void) {

  FGPIOB->PDDR |= (led_mask[0] | led_mask[1] | led_mask[2] );          /* enable PTC5..7 as Output       */
  FGPIOB->PDOR |= (led_mask[0] | led_mask[1] | led_mask[2] );          /* switch Red/Green/Blue LED off  */
}

/*----------------------------------------------------------------------------
  Switch on LEDs
 *----------------------------------------------------------------------------*/
void LED_On (uint32_t led) {

  FGPIOB->PCOR = led_mask[led];
}

/*----------------------------------------------------------------------------
  Switch off LEDs
 *----------------------------------------------------------------------------*/
void LED_Off (uint32_t led) {

  FGPIOB->PSOR = led_mask[led];
}

/*----------------------------------------------------------------------------
  MAIN function
 *----------------------------------------------------------------------------*/
int main (void) {
  int num     = -1; 
  int dir     =  1;

  SystemCoreClockUpdate();                    /* Get Core Clock Frequency     */
  SysTick_Config(SystemCoreClock/1000);       /* Generate interrupt each 1 ms */
  
  LED_Initialize();                             
 
  while(1) {
    /* Calculate 'num': 0,1,...,LED_NUM-1,LED_NUM-1,...,1,0,0,...             */
    num += dir;
    if (num == LED_NUM) { dir = -1; num =  LED_NUM-1; } 
    else if   (num < 0) { dir =  1; num =  0;         }
    LED_On (num);
    Delay(500);
    LED_Off(num);
    Delay(500);
  }
  
}
