#ifndef _C90TFS_DEVICE_H_
#define _C90TFS_DEVICE_H_

#include "SSD_Types.h"

/* one block for each device/algorithm */
/*-----------------------------------------------------------------------*/
#if   defined KE1xZ
  #if FLASH_DERIVATIVE != FTFx_KX_256K_32K_2K_2K_2K
    #error "C90TFS_Device does not match user_cfg.h file."
  #endif

  #if    defined P256_2KBSec || defined D32_2KBSec
    #define FTFx_REG_BASE                 0x40020000u       /* FTFx module base, see reference manual */
    #define PFLASH_BLOCK_BASE             0x00000000u
    #define PFLASH_BLOCK_SIZE             0x00040000u       /* 256 KB size */
    #define DEFLASH_BLOCK_BASE            0x10000000u
    #define DEFLASH_BLOCK_SIZE            0x00010000u       /*  32 KB size */
    #define EERAM_BLOCK_BASE              0x14000000u
    #define EERAM_BLOCK_SIZE              0x00008000u
  #else
    #error "C90TFS_Device does contain Flash sizes."
  #endif

  /* destination to program security key back to flash location */
  #define SECURITY_LOCATION             0x408               /* because we write 8 Bytes */
  #define SECURITY_SIZE                 PGM_SIZE_BYTE

static __inline void Watchdog_Disable(void) {
  (*((vuint32_t *)(0x40052004u))) = 0xD928C520u;          /* WDOG->CNT = WDOG_UPDATE_KEY; */
  (*((vuint32_t *)(0x40052008u))) = 0x0000FFFFu;          /* WDOG->TOVAL = 0xFFFF; */
  (*((vuint32_t *)(0x40052000u))) = 0x00002020u;          /* WDOG->CS = (uint32_t) ((WDOG->CS) & ~WDOG_CS_EN_MASK) | WDOG_CS_UPDATE_MASK; */
}

static __inline void RunMode_Set(void) {
	(*((vuint32_t *)(0xF000300Cu))) = 0xBC00u;              /* disable speculation and cache */
	
  if (((*((vuint32_t *)(0x4007E00Cu))) & 0x60u) == 0x40u) /* if ((SMC_PMCTRL_REG & 0x60) == 0x40)   */ /* Very-Low-Power Run mode (VLPR) selected */
  {
   (*((vuint32_t *)(0x4007E00Cu))) &= 0x9Fu;              /*   SMC_PMCTRL_REG &= 0x9F;              */ /* set Normal Run mode (RUN) */
    while ((*((vuint32_t *)(0x4007E014u))) != 0x01u);     /*   while(SMC_PMSTAT_REG != 0x01u);      */ /* wait until Current power mode is RUN */
  }
}

/*-----------------------------------------------------------------------*/
#elif defined KE1xF
  #if FLASH_DERIVATIVE != FTFx_KX_512K_64K_4K_4K_2K
    #error "C90TFS_Device does not match user_cfg.h file"
  #endif

  #if    defined P256_4KBSec || defined D32_2KBSec
    #define FTFx_REG_BASE                 0x40020000u       /* FTFx module base, see reference manual */
    #define PFLASH_BLOCK_BASE             0x00000000u
    #define PFLASH_BLOCK_SIZE             0x00040000u       /* 256 KB size */
    #define DEFLASH_BLOCK_BASE            0x10000000u
    #define DEFLASH_BLOCK_SIZE            0x00010000u       /*  32 KB size */
    #define EERAM_BLOCK_BASE              0x14000000u
    #define EERAM_BLOCK_SIZE              0x00008000u
  #elif  defined P512_4KBSec || defined D64_2KBSec
    #define FTFx_REG_BASE                 0x40020000u       /* see reference manual */
    #define PFLASH_BLOCK_BASE             0x00000000u
    #define PFLASH_BLOCK_SIZE             0x00080000u       /* 512 KB size */
    #define DEFLASH_BLOCK_BASE            0x10000000u
    #define DEFLASH_BLOCK_SIZE            0x00010000u       /*  64 KB size */
    #define EERAM_BLOCK_BASE              0x14000000u
    #define EERAM_BLOCK_SIZE              0x00008000u
  #else
    #error "C90TFS_Device does contain Flash sizes."
  #endif

  /* destination to program security key back to flash location */
  #define SECURITY_LOCATION             0x408               /* because we write 8 Bytes */
  #define SECURITY_SIZE                 PGM_SIZE_BYTE


static __inline void Watchdog_Disable(void) {
  (*((vuint32_t *)(0x40052004u))) = 0xD928C520u;          /* WDOG->CNT = WDOG_UPDATE_KEY; */
  (*((vuint32_t *)(0x40052008u))) = 0x0000FFFFu;          /* WDOG->TOVAL = 0xFFFF; */
  (*((vuint32_t *)(0x40052000u))) = 0x00002020u;          /* WDOG->CS = (uint32_t) ((WDOG->CS) & ~WDOG_CS_EN_MASK) | WDOG_CS_UPDATE_MASK; */

/* example code from reference manual */
//  (*((vuint32_t *)(0x40052004u))) = 0xD928C520u;
//  while (((*((vuint32_t *)(0x40052000u))) & (1u << 11) ) != 0) __nop();
//  (*((vuint32_t *)(0x40052008u))) = 0x0000FFFFu;
//  (*((vuint32_t *)(0x40052000u))) = 0x00002020u;
//  while (((*((vuint32_t *)(0x40052000u))) & (1u << 10) ) != 0) __nop();
}

static __inline void RunMode_Set(void) {
  if (((*((vuint8_t *)(0x4007E001u))) & 0x60u) == 0x40u)  /* if ((SMC_PMCTRL_REG & 0x60) == 0x40)   */ /* Very-Low-Power Run mode (VLPR) selected */
  {
    (*((vuint8_t *)(0x4007E001u))) &= 0x9Fu;              /*   SMC_PMCTRL_REG &= 0x9F;              */ /* set Normal Run mode (RUN) */
    while ((*((vuint8_t *)(0x4007E003u))) != 0x01u);      /*   while(SMC_PMSTAT_REG != 0x01u);      */ /* wait until Current power mode is RUN */
  }
}



#else
  #error "C90TFS_Device not configured."
#endif

#endif /* #if _C90TFS_DEVICE_H_ */
